

;												
; MAX110 fr ATmega8							
; Bernhard.Erfurt@gmx.de						
; 05/2008										
;												

;												
; Anschlussbelegung PINS						
;												
; PB0 ==> 										
; PB1 ==> MAX232 BUSY							
; PB2 ==> MAX232 CS								
; PB3 ==> MAX232 Din							
; PB4 ==> MAX232 Dout							
; PB5 ==> MAX232 SCLK							
; PB6 ==> Quarz									
; PB7 ==> Quarz									
;												
; PC0 ==> LCD_DATA								
; PC1 ==> LCD_DATA								
; PC2 ==> LCD_DATA								
; PC3 ==> LCD_DATA								
; PC4 ==> LCD RS								
; PC5 ==> LCD E									
;												
; PD0 ==> 										
; PD1 ==> 										
; PD2 ==> 										
; PD3 ==> 										
; PD4 ==> 										
; PD5 ==> LED GRN								
; PD6 ==> LED GELB								
; PD7 ==> LED ROT								
;												


; ATmega8 										
.include "m8def.inc"


; SPI											
.equ SPI_B_CS	= 2
.equ SPI_B_MOSI	= 3
.equ SPI_B_MISO	= 4
.equ SPI_B_SCK	= 5
; LEDS 											
.equ LED_D_GRUEN		= 5
.equ LED_D_GELB			= 6
.equ LED_D_ROT			= 7
; LCD											
.equ LCD_PORT				= PORTC
.equ LCD_D0					= 0
.equ LCD_D1					= 1
.equ LCD_D2					= 2
.equ LCD_D3					= 3
; LCD RS (Befehl/DATEN)							
.equ LCD_RS_PORT			= PORTC
.equ LCD_RS					= 4
; LCD_ENABLE									
.equ LCD_E_PORT				= PORTC
.equ LCD_E					= 5

; SRAM-BELEGUNG ATmega8							
.equ adr_DATEN					= 0x0060			; 0x0060 START Adresse 		

.equ adr_ADC_1_L				= 0x0060+10
.equ adr_ADC_1_H				= 0x0060+11




; REGISTER										

.def NULL 	= R14
.def EINS 	= R15

.def temp 	= R16
.def temp1 	= R17
.def temp2 	= R18
.def temp3 	= R19
.def temp4 	= R20
.def temp5 	= R21
.def temp6 	= R22
.def temp7 	= R23
.def temp8 	= R24
.def temp9 	= R25





.cseg					;Beginn eines Code-Segmentes
.org 0					;Startadresse=0

rjmp RESET      		; Reset Handler                           				
rjmp INTERRUPT_ERROR	;rjmp EXT_INT0   ; IRQ0 Handler                      	
rjmp INTERRUPT_ERROR	;rjmp EXT_INT1   ; IRQ1 Handler                      	
rjmp INTERRUPT_ERROR	;rjmp TIM2_COMP  ; Timer2 Compare Handler            	
rjmp INTERRUPT_ERROR	;rjmp TIM2_OVF   ; Timer2 Overflow Handler           	
rjmp INTERRUPT_ERROR	;rjmp TIM1_CAPT  ; Timer1 Capture Handler            	
rjmp INTERRUPT_ERROR	;rjmp TIM1_COMPA ; Timer1 CompareA Handler           	
rjmp INTERRUPT_ERROR	;rjmp TIM1_COMPB ; Timer1 CompareB Handler           	
rjmp INTERRUPT_ERROR	;rjmp TIM1_OVF   	  	; Timer1 Overflow Handler       
rjmp INTERRUPT_ERROR	;rjmp TIM0_OVF   ; Timer0 Overflow Handler           	
rjmp INTERRUPT_ERROR	;rjmp SPI_STC    ; SPI Transfer Complete Handler     	
rjmp INTERRUPT_ERROR	;rjmp ZEICHEN_EINLESEN 	; USART RX Complete Handler     
rjmp INTERRUPT_ERROR	;rjmp USART_UDRE ; UDR Empty Handler                 	
rjmp INTERRUPT_ERROR	;rjmp USART_TXC  ; USART TX Complete Handler         	
rjmp INTERRUPT_ERROR	;rjmp ADC        ; ADC Conversion Complete Handler   	
rjmp INTERRUPT_ERROR	;rjmp EE_RDY     ; EEPROM Ready Handler              	
rjmp INTERRUPT_ERROR	;rjmp ANA_COMP   ; Analog Comparator Handler         	
rjmp INTERRUPT_ERROR	;rjmp TWSI       ; Two-wire Serial Interface Handler 	
rjmp INTERRUPT_ERROR	;rjmp SPM_RDY    ; Store Program Memory Ready Handler	


; Bei unkorrekten Interrupt aufrufen erfolgt ein RESET ber WDR	
INTERRUPT_ERROR:
	cbi PORTD,LED_D_ROT		; LED ROT			
INTERRUPT_ERROR_SCHLEIFE:
	rjmp INTERRUPT_ERROR_SCHLEIFE

RESET:                        
; STACK initialisieren								
	ldi temp, LOW(RAMEND)
    out SPL, temp
    ldi temp, HIGH(RAMEND)
    out SPH, temp
; SRAM lschen										
SRAM_CLEAR:
	ldi ZL, LOW (adr_DATEN)
	ldi ZH, HIGH(adr_DATEN)
	clr temp
SRAM_CLEAR_w:
	ST z+,temp
	cpi ZH, HIGH(RAMEND); Vergleich?		
	brlo SRAM_CLEAR_w	; kleiner => SPRUNG	
	cpi ZL, LOW(RAMEND)	; Vergleich?		
	brlo SRAM_CLEAR_w	; kleiner => SPRUNG	
	breq SRAM_CLEAR_w	; gleich  => SPRUNG	


; PORT B initialisieren								
	ldi temp, 0b00101100	; SPI 
	out DDRB, temp
; PORT B setzen										
	out PORTB, temp				
; PORT C initialisieren								
	ldi temp, 0b11111111	; DISPLAY	
	out DDRC, temp
; PORT C setzen										
	out PORTC, temp				
; PORT D initialisieren								
	ldi temp, 0b11100000	; LEDs	/TX / RX	
	out DDRD, temp
; PORT D setzen										
	out PORTD, temp				

; Watchdog aktivieren (max. Zeit)					
	ldi TEMP,(1<<WDCE)|(1<<WDE)  
	out wdtcr,TEMP       
	ldi TEMP,(1<<WDE) | (1<<WDP2)|(1<<WDP1)|(1<<WDP0) 
	out wdtcr,temp
; NEUSTART_MIT_WDR									
	rcall NEUSTART_MIT_WDR
; SPI_INITIALISIERUNG								
	rcall SPI_INITIALISIERUNG
; LCD_INITIALISIERUNG								
	rcall LCD_INITIALISIERUNG
; STARTWERTE										
	; NULL				
	clr NULL
	; EINS				
	ldi temp,1
	mov EINS,temp
; ANZEIGE_BEGRUESSUNG								
	rcall ANZEIGE_BEGRUESSUNG
; LED-TEST											
	rcall LED_TEST
; GRN an											
	cbi PORTD,LED_D_GRUEN
; interrupts freigeben								
	sei

; ##############################################################################
; ##############################################################################
; ##############################################################################
LOOP:
	WDR		

	rcall SPI_MAX110_AUSLESEN

	rcall ANZEIGE_WERT_1

	
rjmp LOOP
; ##############################################################################
; ##############################################################################
; ##############################################################################
.include "MAX_LCD.asm"
.include "MAX_SPI.asm"
.include "MAX_SONSTIGES.asm"
; ##############################################################################
; ##############################################################################
; ##############################################################################


TEXT_BEGRUESSUNG_1:
.db "MAX110",0

TEXT_BEGRUESSUNG_2:
.db "30.April 2008",0





