; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_INITIALISIERUNG:
; SPCR => SPIE SPE DORD MSTR CPOL CPHA SPR1 SPR0 (SPI Control Register)		
; 																			
; SPIE: SPI Interrupt Enable												
; SPE:  SPI Enable															
; DORD: Data Order															
; MSTR: Master/Slave Select													
; CPOL: Clock Polarity														
; CPHA: Clock Phase															
;						   Leading Edge 	Trailing Edge 		SPI Mode	
;		CPOL = 0, CPHA = 0 Sample (Rising) 	Setup (Falling) 		0		
;		CPOL = 0, CPHA = 1 Setup (Rising) 	Sample (Falling) 		1		
;		CPOL = 1, CPHA = 0 Sample (Falling) Setup (Rising) 			2		
;		CPOL = 1, CPHA = 1 Setup (Falling) 	Sample (Rising) 		3		
; SPR1: SPI Clock Rate Select 1												
; SPR0: SPI Clock Rate Select 0												
; 		SPR1 SPR0 SCK Frequency												
;  		0    0   fosc/4														
;  		0    1   fosc/16													
;  		1    0   fosc/64													
;  		1    1   fosc/128													
;																			
; Enable SPI, Master, set clock rate fck/128								
	ldi temp,(0<<SPIE)|(1<<SPE)|(0<<DORD)|(1<<MSTR)|(0<<CPOL)|(0<<CPHA)|(1<<SPR1)|(1<<SPR0)
	out SPCR,temp

; SPSR => SPIF WCOL - - - - - SPI2X  (SPI Status Register )					
;																			
; SPIF:  SPI Interrupt Flag													
; WCOL:  Write COLlision Flag												
; SPI2X: Double SPI Speed Bit												
;																			
; Double SPI Speed = off													
	ldi temp,(0<<SPI2X)
	out SPSR,temp	

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; input: TEMP																	
;																				
;	rcall SPI_SENDEN_EINLESEN	; INP: TEMP OUT: temp							
;																				
SPI_SENDEN_EINLESEN:
	; Start transmission of data 	
	out SPDR,temp
	; Wait for transmission complete
SPI_SENDEN_w:
	sbis SPSR,SPIF
	rjmp SPI_SENDEN_w
	; DATENBYTE EINLESEN			
	in temp, SPDR	; einlesen  
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_MAX110_AUSLESEN:

	rcall SPI_BUSY_WAIT

	rcall wait_100ms
	rcall wait_100ms
	rcall wait_100ms
		
	; CS auf LOW		
	cbi PORTB,(SPI_B_CS)
	cbi PORTD,LED_D_GELB	; GELB 	
	
	rcall wait5ms

	; 		   NOOP 		
	;		   |NU 			
	;		   ||NU 		
	;		   |||CONV4 	
	;		   ||||CONV3 	
	;		   |||||CONV2 	
	;		   ||||||CONV1 	
	;		   |||||||DV4	
	;		   ||||||||		
	ldi temp,0b10001101			
	rcall SPI_SENDEN_EINLESEN	; INP: TEMP OUT: temp	
	STS(adr_ADC_1_H),temp
	;		   DV2 			
	;		   |NU 			
	;		   ||NU 		
	;		   |||CHS 		
	;		   ||||CAL 		
	;		   |||||NUL 	
	;		   ||||||PDX 	
	;		   |||||||PD	
	;		   ||||||||		
	ldi temp,0b00000000			
	rcall SPI_SENDEN_EINLESEN	; INP: TEMP OUT: temp	
	STS(adr_ADC_1_L),temp

	; CS auf HIGH		
	sbi PORTB,(SPI_B_CS)
	sbi PORTD,LED_D_GELB	; GELB 	


ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SPI_BUSY_WAIT:

	; BUSY abfragen	
	in temp,PINB
	andi temp,0b00000010
	tst temp
	brne SPI_BUSY_WAIT_OK
	; Schleife		
	WDR
	cbi PORTD,LED_D_ROT		;	ROT
	rjmp SPI_BUSY_WAIT

SPI_BUSY_WAIT_OK:
	sbi PORTD,LED_D_ROT		;	ROT
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################